# $Log: Uploader.py,v $
# Revision 1.4  2000/05/04 08:42:46  itamar
# *** empty log message ***
#
# Revision 1.3  2000/05/01 15:47:50  itamar
# Removed 'old' option - we're no longer compatible with 1.x.
# Abort setting properties on html pages if initial upload failed.
#
# Revision 1.2  2000/04/24 10:40:06  itamar
# Handle keyword and description properties returned by html parser.
#

import sys, os, string
import Client, htmlutils

global ServerError
ServerError=Client.ServerError

class Uploader:
    """ Uploads file into Zope using ZPublisher's Client """
    
    def __init__(self, verbose=0, doctor=0, clean=0, removejs=0, index_html=0):
        self.verbose = verbose
        self.doctor = doctor
        self.clean = clean
        self.removejs = doctor and removejs
        self.index_html = index_html
    
    def setOptions(self, **kwargs):
        optionslist = ('verbose', 'doctor', 'clean', 'removejs', 'index_html')
        
        for option in kwargs.keys():
            if option in optionslist: setattr(self, option, kwargs[option])
                   
    def call(self, func, *args, **kw):
        # Call a function ignoring redirect bci errors.
        try: apply(func, args, kw)        
        except ServerError, v:
            if str(v)[:1] != '3':
               raise sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2]
            return 0
        except: #handle other cases
            error = string.split(str(sys.exc_info()[1]), '\n')[1]
            code = error[0:3]
            if code == '404':
                msg = 'The URL you are uploading to does not exist.'
            elif code == '400':
                if kw.has_key('id'):
                    msg = '''The file %s was not uploaded to %s since
                    it has a bad id.''' % (kw['id'], func.url)
                else:
                    raise sys.exc_info()[0], sys.exc_info()[1], sys.exc_info()[2]
            print msg
            return 0
        else:
            return 1
            
    def upload_file(self, object, f):
        if os.path.isdir(f): return self.upload_dir(object, f)
        dir, name = os.path.split(f)
        root, ext = os.path.splitext(name)
        if ext in ('file', 'dir'): ext=''
        else:
            ext=string.lower(ext)
            if ext and ext[0] in '.': ext=ext[1:]
        if ext and hasattr(self, 'upload_'+ext):
            if self.verbose: print 'upload_'+ext, f
            return getattr(self, 'upload_'+ext)(object, f)

        if self.verbose: print 'upload_file', f, ext
        self.call(object.manage_addFile, id=name, file=open(f, 'rb'))

    def upload_dir(self, object, f):        
        if f[-1] == os.sep: f = f[:-1] #remove '/' from end of directory name
        
        if self.verbose: print 'upload_dir', f  
        dir, name = os.path.split(f)
        self.call(object.manage_addFolder, id=name)
        object=object.__class__(object.url+'/'+name,
                                username=object.username,
                                password=object.password)
        for n in os.listdir(f):
            self.upload_file(object, os.path.join(f,n))

    def upload_html(self, object, f):
        dir, name = os.path.split(f)
        f=open(f)

        if self.doctor: 
            title, head, bodyattribs, body, keywords, description = \
                                     htmlutils.parse_html(f, self.removejs)
        else:
            title, head, bodyattribs, body, keywords, description = \
                        '', '', '', f.read(), [], ""

        if self.clean:
            title = htmlutils.clean_html(title)
            head = htmlutils.clean_html(head)
            body = htmlutils.clean_html(body)
            description = htmlutils.clean_html(description)

        suceeded = self.call(object.manage_addDTMLDocument, id=name,
                             title=title, file=body)
        #if not suceeded: return None
        
        if self.index_html and name in ('index.html', 'index.htm'):
            self.call(object.manage_addDTMLMethod, id='index_html',
                 file=('<dtml-raise Redirect>'
                       '<dtml-var URL1>/%s'
                       '</dtml-raise>' % name
                       ))

        # Now add META and other tags as property, and BODY atrtributes
        # as property
        object=object.__class__(object.url+'/'+name,
                                username=object.username,
                                password=object.password)

        if head:
            self.call(object.manage_addProperty,
               id="loadsite_head", type="text", value=head)

        if bodyattribs:
            self.call(object.manage_addProperty,
               id="loadsite_bodyattribs", type="string", value=bodyattribs)
        
        if keywords:
            keywords = string.join(keywords, '\n')
            self.call(object.manage_addProperty,
               id="loadsite_keywords", type="lines", value=keywords)  
        
        if bodyattribs:
            self.call(object.manage_addProperty,
               id="loadsite_description", type="string", value=description)
               
    upload_htm=upload_html

    def upload_dtml(self, object, f):
        dir, name = os.path.split(f)
        f=open(f)

        self.call(object.manage_addDTMLMethod, id=name, file=f)


    def upload_gif(self, object, f):
        dir, name = os.path.split(f)
        self.call(object.manage_addImage, id=name, file=open(f, 'rb'))

    upload_jpg=upload_gif
    upload_jpeg=upload_gif
    upload_png=upload_gif

