#!/usr/bin/python
"""LoadSite version 1.2
Based on load_site.py from Digital Creations

Modified by Oleg Broytmann <phd2@earthling.net>
Modified by Itamar Shtull-Trauring <itamars@ibm.net>

This version of load_site.py is now a standalone program - it does not require Zope, as I've bundled ZPublisher.Client with it.  Therefore the -p command line option is now depreciated.

--------------------------------------------------------------------------------

If you need to upload files into your Zope site, you can use either FTP
or load_site.py.  load_site's advatantages are the fact that it will work
even if you don't have ftp access to your site and can only view it from
your browser.  Additionaly load_site can process files before uploading them.
For example, the -D option will remove the header and footer of your html
pages, and replace them with <dtml-var standard_html_header/footer>.

For example, to upload all html files in the current directory into the /test
folder in your local zope install, while replacing <html>...<body> with
<dtml-var standard_html_header>, you would run:

    python ./load_site.py -u superuser:123 -D http://localhost:8080/test *.html *.htm

    
Usage: python load_site.py [-u user:password] [options] url file ....


   This option must appear before the other options:
    
      -u user:password

         Credentials


   Other options:

      -D

         For HTML documents, replace the start of the content, up to
         and including the opening body tag with a DTML var tag that
         inserts the standard header. Also replace the closing body
         and html tag with a DTML var tag that inserts the standard
         footer.  
         
         The contents of <head></head> and the attributes of
         <body> will be stored in properties of the document called
         'loadsite_head' and 'loadsite_bodyattribs'.  The document's
         title will be stored in the 'title' property.

      -j
      
         Remove Javascript tags from header, if you are using the -D option.
      
      -I
      
         For each index.html, add an index_html that redirects to it.
         
      -c
	  
         Clean up garbage from Windows text (e.g. quotes that appear
         as question marks.)
         		 
      -v

         Run in verbose mode.
"""

import sys, getopt, os, string
from LoadSite import Client
from LoadSite.Uploader import Uploader

def main():
    user, password = 'superuser', '123'
    opts, args = getopt.getopt(sys.argv[1:], 'p:u:DIvcj')
    verbose=0
    doctor=0
    clean=0
    removejs=0
    index_html=0

    for o, v in opts:
        if o=='-p':
            print "The '-p' option is no longer needed in this version."
        if o=='-u':
            v = string.split(v,':')
            user, password = v[0], string.join(v[1:],':')
        elif o=='-D': doctor=1
        elif o=='-v': verbose=1
        elif o=='-c': clean=1
        elif o=='-j': 
            removejs = 1
            if not doctor:
                print "The -j option can only be used with the -D option."
                sys.exit(1)
        elif o=='-I': index_html=1

    if not args:
        print __doc__
        sys.exit(1)

    url=args[0]
    files=args[1:]

    object=Client.Object(url, username=user, password=password)

    u = Uploader(verbose, doctor, clean, removejs, index_html)
    for f in files: u.upload_file(object, f)


if __name__=='__main__': main()
